%global srcname oauth2client
%global sum Python client library for OAuth 2.0
# Share doc between python- and python3-
%global _docdir_fmt %{name}


%if 0%{?fedora}
%bcond_without python3
%else
%bcond_with python3
%endif

%global with_docs 0

Name:           python-%{srcname}
Version:        1.5.2
Release:        3%{?dist}.1
Summary:        %{sum}

Group:          Development/Languages
License:        ASL 2.0
URL:            https://github.com/google/%{srcname}
Source0:        https://github.com/google/%{srcname}/archive/v%{version}.tar.gz#/%{srcname}-%{version}.tar.gz
Patch0:         remove-python-shebang-from-module.patch
Patch1:         docs-build-fix.patch

BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  python-setuptools
# Needed for docs build
BuildRequires:  pyOpenSSL
BuildRequires:  python-django
BuildRequires:  python-flask
BuildRequires:  python-gflags
BuildRequires:  python-httplib2 >= 0.9.1
BuildRequires:  python-keyring
BuildRequires:  python-pyasn1 >= 0.1.7
BuildRequires:  python-pyasn1-modules >= 0.0.5
BuildRequires:  python-rsa >= 3.1.4
BuildRequires:  python-six >= 1.6.1
%if %{with python3}
BuildRequires:  python3-setuptools
BuildRequires:  python3-devel
%endif

%description
This is a python client module for accessing resources protected by OAuth 2.0

%package -n python2-%{srcname}
Summary:        %{sum}
%{?python_provide:%python_provide python2-%{srcname}}

Requires:       pyOpenSSL
Requires:       python-gflags
Requires:       python-httplib2 >= 0.9.1
Requires:       python-keyring
Requires:       python-pyasn1 >= 0.1.7
Requires:       python-pyasn1-modules >= 0.0.5
Requires:       python-rsa >= 3.1.4
Requires:       python-six >= 1.6.1

%description -n python2-%{srcname}
This is a python client module for accessing resources protected by OAuth 2.0


%if %{with python3}
%package -n python3-%{srcname}
Summary:        %{sum}
%{?python_provide:%python_provide python3-%{srcname}}

Requires:       python3-pyOpenSSL
Requires:       python3-gflags
Requires:       python3-httplib2 >= 0.9.1
Requires:       python3-keyring
Requires:       python3-pyasn1 >= 0.1.7
Requires:       python3-pyasn1-modules >= 0.0.5
Requires:       python3-rsa >= 3.1.4
Requires:       python3-six >= 1.6.1

%description -n python3-%{srcname}
This is a python client module for accessing resources protected by OAuth 2.0
%endif

%if 0%{?with_docs}
%package doc
Summary:        Documentation for python oauth2client
BuildRequires:  python-sphinx > 1.3
BuildRequires:  python-sphinx_rtd_theme

%description doc
The python-oauth2client-doc package provides the documentation
for the package. Documentation is shipped in html format.
%endif

%prep
%setup -q -n %{srcname}-%{version}
%patch0 -p1 
%patch1 -p1 

# We do not have the package for google.appengine support
# This is removed because it breaks the docs build otherwise
rm -f docs/source/oauth2client.appengine.rst oauth2client/appengine.py

%if %{with python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
%endif

%build
%py2_build
export PYTHONPATH=`pwd`
%if 0%{?with_docs}
pushd docs
# Not running with smp_flags as sometimes sphinx fails when run
# with parallel make
make html
popd
%endif
unset PYTHONPATH
rm -vrf docs/_build/html/_sources
rm -vrf docs/_build/html/_static/fonts
rm -fv docs/_build/html/{.buildinfo,objects.inv}


%if %{with python3}
pushd %{py3dir}
%py3_build
popd
%endif

%install
%py2_install

%if %{with python3}
pushd %{py3dir}
%py3_install
popd
%endif

%files -n python2-%{srcname}
%license LICENSE
%doc CHANGELOG.md CONTRIBUTING.md README.md 
%{python2_sitelib}/%{srcname}
%{python2_sitelib}/%{srcname}-%{version}-*.egg-info

%if 0%{?with_docs}
%files doc
%doc docs/_build/html
%endif

%if %{with python3}
%files -n python3-%{srcname}
%license LICENSE 
%doc CHANGELOG.md CONTRIBUTING.md README.md 
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{srcname}*.egg-info
%endif

%changelog
* Wed Jan 20 2016 Haïkel Guémar <hguemar@fedoraproject.org> - 1.5.2-3
- Fix Build in CentOS
- Make doc build conditional

* Thu Nov 26 2015 Michele Baldessari <michele@acksyn.org> - 1.5.2-2
- Remove dependency on sphinx-contrib-napoleon now that sphinx is at version >= 1.3
- Tighten versioned dependencies
- Update to latest python policy
* Thu Nov 19 2015 Michele Baldessari <michele@acksyn.org> - 1.5.2-1
- New upstream (BZ 1283443)
* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.1-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5
* Tue Oct 13 2015 Michele Baldessari <michele@acksyn.org> - 1.5.1-2
- Add versioned requires as per setup.py
* Thu Sep 17 2015 Michele Baldessari <michele@acksyn.org> - 1.5.1-1
- New upstream (BZ#1263881)
* Fri Sep 04 2015 Michele Baldessari <michele@acksyn.org> - 1.5.0-1
- New upstream (BZ#1259966)
* Sun Jul 12 2015 Michele Baldessari <michele@acksyn.org> - 1.4.12-1
- New upstream (BZ#1241304)
* Mon Jun 22 2015 Michele Baldessari <michele@acksyn.org> - 1.4.11-2
- Use -O1 for python3 as well
- Use python2 macros
- Remove the extra fonts from the -doc package
* Thu Jun 04 2015 Michele Baldessari <michele@acksyn.org> - 1.4.11-1
- Initial packaging
